@@ -7,9 +7,4 @@ Puppet::Type.type(:eswitchd_config).provide(
     '/etc/neutron/plugins/ml2/eswitchd.conf'
   end
 
-  # added for backwards compatibility with older versions of inifile
-  def file_path
-    self.class.file_path
-  end
-
 end
