@@ -12,6 +12,8 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/l2gateway_agent.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf.ini',
                      '/etc/neutron/vpn_agent.ini',
+                     '/etc/neutron/neutron_vpnaas.conf',
+                     '/etc/neutron/taas_plugin.ini',
                      '/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
                      '/etc/neutron/plugins/ml2/linuxbridge_agent.ini',
                      '/etc/neutron/plugins/ml2/openvswitch_agent.ini',
@@ -31,6 +33,8 @@ describe 'basic neutron_config resource' do
   File <||> -> Neutron_plugin_ml2 <||>
   File <||> -> Neutron_l2gw_service_config <||>
   File <||> -> Neutron_vpnaas_agent_config <||>
+  File <||> -> Neutron_vpnaas_service_config <||>
+  File <||> -> Neutron_taas_service_config <||>
   File <||> -> Neutron_plugin_opencontrail <||>
   File <||> -> Neutron_agent_linuxbridge <||>
   File <||> -> Neutron_agent_ovs <||>
@@ -55,6 +59,8 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/l2gateway_agent.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf.ini',
                      '/etc/neutron/vpn_agent.ini',
+                     '/etc/neutron/neutron_vpnaas.conf',
+                     '/etc/neutron/taas_plugin.ini',
                      '/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
                      '/etc/neutron/plugins/ml2/linuxbridge_agent.ini',
                      '/etc/neutron/plugins/ml2/openvswitch_agent.ini',
@@ -213,6 +219,42 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
+  neutron_vpnaas_service_config { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_vpnaas_service_config { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_vpnaas_service_config { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_vpnaas_service_config { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_taas_service_config { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_taas_service_config { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_taas_service_config { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_taas_service_config { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
   neutron_plugin_opencontrail { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -367,6 +409,8 @@ describe 'basic neutron_config resource' do
                     'neutron_metering_agent_config',
                     'neutron_plugin_ml2',
                     'neutron_vpnaas_agent_config',
+                    'neutron_vpnaas_service_config',
+                    'neutron_taas_service_config',
                     'neutron_plugin_opencontrail',
                     'neutron_agent_linuxbridge',
                     'neutron_agent_ovs',
