@@ -27,13 +27,28 @@ describe 'neutron::config' do
       { :api_paste_ini => config_hash }
     end
 
-    it 'configures arbitrary neutron-api-config configurations' do
+    it 'configures arbitrary neutron-api-paste configurations' do
       should contain_neutron_api_paste_ini('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_api_paste_ini('DEFAULT/bar').with_value('barValue')
       should contain_neutron_api_paste_ini('DEFAULT/baz').with_ensure('absent')
     end
   end
 
+
+  shared_examples 'neutron_rootwrap_config' do
+    let :params do
+      { :rootwrap_config => config_hash }
+    end
+
+    it { should contain_class('neutron::deps') }
+
+    it 'configures arbitrary rootwrap configurations' do
+      should contain_neutron_rootwrap_config('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_rootwrap_config('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_rootwrap_config('DEFAULT/baz').with_ensure('absent')
+    end
+  end
+
   shared_examples 'neutron_service_config' do
     let :params do
       { :sfc_service_config  => config_hash,
@@ -66,6 +81,8 @@ describe 'neutron::config' do
         :metadata_agent_config    => config_hash,
         :metering_agent_config    => config_hash,
         :vpnaas_agent_config      => config_hash,
+        :vpnaas_service_config    => config_hash,
+        :taas_service_config      => config_hash,
         :l2gw_agent_config        => config_hash,
         :bgp_dragent_config       => config_hash,
       }
@@ -131,6 +148,18 @@ describe 'neutron::config' do
       should contain_neutron_vpnaas_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary vpnaas_service_config configurations' do
+      should contain_neutron_vpnaas_service_config('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_vpnaas_service_config('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_vpnaas_service_config('DEFAULT/baz').with_ensure('absent')
+    end
+
+    it 'configures arbitrary taas_service_config configurations' do
+      should contain_neutron_taas_service_config('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_taas_service_config('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_taas_service_config('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary l2gw_agent_config configurations' do
       should contain_neutron_l2gw_agent_config('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_l2gw_agent_config('DEFAULT/bar').with_value('barValue')
@@ -149,7 +178,6 @@ describe 'neutron::config' do
     let :params do
       {
         :plugin_opencontrail_config    => config_hash,
-        :plugin_nuage_config           => config_hash,
         :plugin_ml2_config             => config_hash
       }
     end
@@ -160,12 +188,6 @@ describe 'neutron::config' do
       should contain_neutron_plugin_opencontrail('DEFAULT/baz').with_ensure('absent')
     end
 
-    it 'configures arbitrary neutron_plugin_nuage configurations' do
-      should contain_neutron_plugin_nuage('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_nuage('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_nuage('DEFAULT/baz').with_ensure('absent')
-    end
-
     it 'configures arbitrary neutron_plugin_ml2 configurations' do
       should contain_neutron_plugin_ml2('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_plugin_ml2('DEFAULT/bar').with_value('barValue')
@@ -184,6 +206,7 @@ describe 'neutron::config' do
 
       it_behaves_like 'neutron_config'
       it_behaves_like 'neutron_api_paste_ini'
+      it_behaves_like 'neutron_rootwrap_config'
       it_behaves_like 'neutron_service_config'
       it_behaves_like 'neutron_agent_config'
       it_behaves_like 'neutron_plugin_config'
