@@ -27,8 +27,16 @@ describe 'neutron::plugins::ml2::ovn' do
       :disable_ovn_dhcp_for_baremetal_ports => '<SERVICE DEFAULT>',
       :dns_servers                          => '<SERVICE DEFAULT>',
       :vhostuser_socket_dir                 => '<SERVICE DEFAULT>',
+      :dhcp_default_lease_time              => '<SERVICE DEFAULT>',
+      :ovn_dhcp4_global_options             => '<SERVICE DEFAULT>',
+      :ovn_dhcp6_global_options             => '<SERVICE DEFAULT>',
       :ovn_emit_need_to_frag                => '<SERVICE DEFAULT>',
       :localnet_learn_fdb                   => '<SERVICE DEFAULT>',
+      :fdb_age_threshold                    => '<SERVICE DEFAULT>',
+      :mac_binding_age_threshold            => '<SERVICE DEFAULT>',
+      :ignore_lsp_down                      => '<SERVICE DEFAULT>',
+      :fdb_removal_limit                    => '<SERVICE DEFAULT>',
+      :mac_binding_removal_limit            => '<SERVICE DEFAULT>',
       :network_log_rate_limit               => '<SERVICE DEFAULT>',
       :network_log_burst_limit              => '<SERVICE DEFAULT>',
       :network_log_local_output_log_base    => '<SERVICE DEFAULT>',
@@ -63,8 +71,16 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/disable_ovn_dhcp_for_baremetal_ports').with_value(p[:disable_ovn_dhcp_for_baremetal_ports])
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers])
         should contain_neutron_plugin_ml2('ovn/vhost_sock_dir').with_value(p[:vhostuser_socket_dir])
+        should contain_neutron_plugin_ml2('ovn/dhcp_default_lease_time').with_value(p[:dhcp_default_lease_time])
+        should contain_neutron_plugin_ml2('ovn/ovn_dhcp4_global_options').with_value(p[:ovn_dhcp4_global_options])
+        should contain_neutron_plugin_ml2('ovn/ovn_dhcp6_global_options').with_value(p[:ovn_dhcp6_global_options])
         should contain_neutron_plugin_ml2('ovn/ovn_emit_need_to_frag').with_value(p[:ovn_emit_need_to_frag])
         should contain_neutron_plugin_ml2('ovn/localnet_learn_fdb').with_value(p[:localnet_learn_fdb])
+        should contain_neutron_plugin_ml2('ovn/fdb_age_threshold').with_value(p[:fdb_age_threshold])
+        should contain_neutron_plugin_ml2('ovn/mac_binding_age_threshold').with_value(p[:mac_binding_age_threshold])
+        should contain_neutron_plugin_ml2('ovn_nb_global/ignore_lsp_down').with_value(p[:ignore_lsp_down])
+        should contain_neutron_plugin_ml2('ovn_nb_global/fdb_removal_limit').with_value(p[:fdb_removal_limit])
+        should contain_neutron_plugin_ml2('ovn_nb_global/mac_binding_removal_limit').with_value(p[:mac_binding_removal_limit])
         should contain_neutron_plugin_ml2('network_log/rate_limit').with_value(p[:network_log_rate_limit])
         should contain_neutron_plugin_ml2('network_log/burst_limit').with_value(p[:network_log_burst_limit])
         should contain_neutron_plugin_ml2('network_log/local_output_log_base').with_value(p[:network_log_local_output_log_base])
@@ -89,8 +105,17 @@ describe 'neutron::plugins::ml2::ovn' do
           :dvr_enabled                          => false,
           :disable_ovn_dhcp_for_baremetal_ports => false,
           :dns_servers                          => '8.8.8.8,10.10.10.10',
+          :vhostuser_socket_dir                 => '/var/run/openvswitch',
+          :dhcp_default_lease_time              => 43200,
+          :ovn_dhcp4_global_options             => 'ntp_server:1.2.3.4',
+          :ovn_dhcp6_global_options             => 'ntp_server:5.6.7.8',
           :ovn_emit_need_to_frag                => false,
           :localnet_learn_fdb                   => false,
+          :fdb_age_threshold                    => 10,
+          :mac_binding_age_threshold            => 11,
+          :ignore_lsp_down                      => false,
+          :fdb_removal_limit                    => 12,
+          :mac_binding_removal_limit            => 13,
         }
       end
 
@@ -111,8 +136,16 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/disable_ovn_dhcp_for_baremetal_ports').with_value(p[:disable_ovn_dhcp_for_baremetal_ports])
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers])
         should contain_neutron_plugin_ml2('ovn/vhost_sock_dir').with_value(p[:vhostuser_socket_dir])
+        should contain_neutron_plugin_ml2('ovn/dhcp_default_lease_time').with_value(p[:dhcp_default_lease_time])
+        should contain_neutron_plugin_ml2('ovn/ovn_dhcp4_global_options').with_value(p[:ovn_dhcp4_global_options])
+        should contain_neutron_plugin_ml2('ovn/ovn_dhcp6_global_options').with_value(p[:ovn_dhcp6_global_options])
         should contain_neutron_plugin_ml2('ovn/ovn_emit_need_to_frag').with_value(p[:ovn_emit_need_to_frag])
         should contain_neutron_plugin_ml2('ovn/localnet_learn_fdb').with_value(p[:localnet_learn_fdb])
+        should contain_neutron_plugin_ml2('ovn/fdb_age_threshold').with_value(p[:fdb_age_threshold])
+        should contain_neutron_plugin_ml2('ovn/mac_binding_age_threshold').with_value(p[:mac_binding_age_threshold])
+        should contain_neutron_plugin_ml2('ovn_nb_global/ignore_lsp_down').with_value(p[:ignore_lsp_down])
+        should contain_neutron_plugin_ml2('ovn_nb_global/fdb_removal_limit').with_value(p[:fdb_removal_limit])
+        should contain_neutron_plugin_ml2('ovn_nb_global/mac_binding_removal_limit').with_value(p[:mac_binding_removal_limit])
         should contain_neutron_plugin_ml2('network_log/rate_limit').with_value(p[:network_log_rate_limit])
         should contain_neutron_plugin_ml2('network_log/burst_limit').with_value(p[:network_log_burst_limit])
         should contain_neutron_plugin_ml2('network_log/local_output_log_base').with_value(p[:network_log_local_output_log_base])
@@ -134,9 +167,11 @@ describe 'neutron::plugins::ml2::ovn' do
     context 'with parameters set by arrays' do
       let :params do
         {
-          :ovn_nb_connection => ['tcp:192.0.2.11:6641', 'tcp:192.0.2.12:6641'],
-          :ovn_sb_connection => ['tcp:192.0.2.11:6642', 'tcp:192.0.2.12:6642'],
-          :dns_servers       => ['8.8.8.8', '10.10.10.10'],
+          :ovn_nb_connection        => ['tcp:192.0.2.11:6641', 'tcp:192.0.2.12:6641'],
+          :ovn_sb_connection        => ['tcp:192.0.2.11:6642', 'tcp:192.0.2.12:6642'],
+          :dns_servers              => ['8.8.8.8', '10.10.10.10'],
+          :ovn_dhcp4_global_options => ['ntp_server:1.2.3.4', 'wpad:1.2.3.5'],
+          :ovn_dhcp6_global_options => ['ntp_server:5.6.7.8', 'wpad:5.6.7.9'],
         }
       end
 
@@ -144,6 +179,8 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/ovn_nb_connection').with_value(p[:ovn_nb_connection].join(','))
         should contain_neutron_plugin_ml2('ovn/ovn_sb_connection').with_value(p[:ovn_sb_connection].join(','))
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers].join(','))
+        should contain_neutron_plugin_ml2('ovn/ovn_dhcp4_global_options').with_value(p[:ovn_dhcp4_global_options].join(','))
+        should contain_neutron_plugin_ml2('ovn/ovn_dhcp6_global_options').with_value(p[:ovn_dhcp6_global_options].join(','))
       end
     end
   end
