@@ -18,7 +18,6 @@ describe 'neutron::server' do
       :enabled                  => true,
       :auth_strategy            => 'keystone',
       :sync_db                  => false,
-      :router_scheduler_driver  => 'neutron.scheduler.l3_agent_scheduler.ChanceScheduler',
     }
   end
 
@@ -83,13 +82,19 @@ describe 'neutron::server' do
       should contain_neutron_config('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
+      should contain_neutron_config('DEFAULT/network_scheduler_driver').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('DEFAULT/router_scheduler_driver').with_value('<SERVICE DEFAULT>')
       should contain_oslo__middleware('neutron_config').with(
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
         :max_request_body_size        => '<SERVICE DEFAULT>',
       )
       should contain_neutron_config('ovs/integration_bridge').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('ovs/igmp_flood').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('ovs/igmp_flood_reports').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('ovs/igmp_flood_unregistered').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('DEFAULT/enable_default_route_ecmp').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('DEFAULT/enable_default_route_bfd').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -227,20 +232,20 @@ describe 'neutron::server' do
 
     context 'with availability zone hints set' do
       before :each do
-        params.merge!( :dhcp_load_type             => 'networks',
-                       :router_scheduler_driver    => 'neutron.scheduler.l3_agent_scheduler.AZLeastRoutersScheduler',
-                       :network_scheduler_driver   => 'neutron.scheduler.dhcp_agent_scheduler.AZAwareWeightScheduler',
-                       :default_availability_zones => ['zone1', 'zone2']
-        )
+        params.merge!({
+          :dhcp_load_type             => 'networks',
+          :router_scheduler_driver    => 'neutron.scheduler.l3_agent_scheduler.AZLeastRoutersScheduler',
+          :network_scheduler_driver   => 'neutron.scheduler.dhcp_agent_scheduler.AZAwareWeightScheduler',
+          :default_availability_zones => ['zone1', 'zone2']
+        })
       end
 
       it 'should configure neutron server for availability zones' do
         should contain_neutron_config('DEFAULT/default_availability_zones').with_value('zone1,zone2')
-        should contain_neutron_config('DEFAULT/router_scheduler_driver').with_value('neutron.scheduler.l3_agent_scheduler.AZLeastRoutersScheduler')
         should contain_neutron_config('DEFAULT/network_scheduler_driver').with_value('neutron.scheduler.dhcp_agent_scheduler.AZAwareWeightScheduler')
+        should contain_neutron_config('DEFAULT/router_scheduler_driver').with_value('neutron.scheduler.l3_agent_scheduler.AZLeastRoutersScheduler')
         should contain_neutron_config('DEFAULT/dhcp_load_type').with_value('networks')
       end
-
     end
 
     context 'with enable_proxy_headers_parsing' do
@@ -339,6 +344,36 @@ describe 'neutron::server' do
       end
     end
 
+    context 'with IGMP flood enabled' do
+      before :each do
+        params.merge!({
+          :igmp_flood              => true,
+          :igmp_flood_reports      => true,
+          :igmp_flood_unregistered => true,
+        })
+      end
+
+      it 'configure neutron.conf' do
+        should contain_neutron_config('ovs/igmp_flood').with_value(true)
+        should contain_neutron_config('ovs/igmp_flood_reports').with_value(true)
+        should contain_neutron_config('ovs/igmp_flood_unregistered').with_value(true)
+      end
+    end
+
+    context 'with default route options' do
+      before :each do
+        params.merge!({
+          :enable_default_route_ecmp => false,
+          :enable_default_route_bfd  => false,
+        })
+      end
+
+      it 'configure neutron.conf' do
+        should contain_neutron_config('DEFAULT/enable_default_route_ecmp').with_value(false)
+        should contain_neutron_config('DEFAULT/enable_default_route_bfd').with_value(false)
+      end
+    end
+
     context 'with VPNaaS package installation' do
       before do
         params.merge!(
